==> IWB2011_0.0.1.zip: IWB2011/doc/R-Introduction.R <==
###################################################
### chunk number 1: setup
###################################################
#line 17 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
options(width = 40)


###################################################
### chunk number 2: vectors
###################################################
#line 58 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
v <- 123
s <- "a string"
t <- TRUE
letters            # 'letters' is a built-in variable
length(letters)    # 'length' is a function


###################################################
### chunk number 3: vectorsRepAndSeq
###################################################
#line 75 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
seq(1, 3) 
1:3
rep(1:2, 3)
vector(mode="character", length=5)


###################################################
### chunk number 4: names1
###################################################
#line 90 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
x <- c(a=0, b=2)
x
names(x) <- c("Australia", "Brazil")
x


###################################################
### chunk number 5: posind
###################################################
#line 119 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
x <- 1:10
x[2]
x[1:3]


###################################################
### chunk number 6: posind2
###################################################
#line 126 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
 x[9:11]


###################################################
### chunk number 7: posind3
###################################################
#line 138 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
x[0:1]
x[c(0, 0, 0)]


###################################################
### chunk number 8: posind4
###################################################
#line 144 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
x[c(10, 2, NA)]


###################################################
### chunk number 9: posassign
###################################################
#line 155 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
x[2] <- 200
x[8:10] <- 10
x


###################################################
### chunk number 10: negsub
###################################################
#line 170 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
x[-(1:3)]


###################################################
### chunk number 11: negassignb
###################################################
#line 189 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
x = 1:10
x[-(8:10)] = 10
x


###################################################
### chunk number 12: logicalsub
###################################################
#line 205 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
x = 1:10
x > 5
x[x > 5]


###################################################
### chunk number 13: namedsub
###################################################
#line 225 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
x <- c(a=1, b=2, c=3)
x[c("c", "a", "foo")]



###################################################
### chunk number 14: vec1
###################################################
#line 243 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
1:3 + 10:12


###################################################
### chunk number 15: vec2
###################################################
#line 248 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
 1 + 1:5
 paste(1:5, "A", sep="")


###################################################
### chunk number 16: factor
###################################################
#line 266 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
col <- c("red", "green", "red", "yellow", "red")
factor(col)


###################################################
### chunk number 17: matrixEx
###################################################
#line 283 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
x <- matrix(1:10, nrow=2)
dim(x)
x
as.vector(x)


###################################################
### chunk number 18: names2
###################################################
#line 292 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
x <- matrix(c(4, 8, 5, 6, 4, 2, 1, 5, 7), nrow=3)
dimnames(x) <- list(
  year = c("2005", "2006", "2007"), 
  "mode of transport" = c("plane", "bus", "boat"))
x


###################################################
### chunk number 19: arraysub
###################################################
#line 322 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
 x = matrix(1:9, ncol=3)
 x[ x > 6 ]
 x[row(x) > col(x)] = 0
 x


###################################################
### chunk number 20: listenv
###################################################
#line 340 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
 lst = list(a=1:3, b = "ciao", c = sqrt)
 lst
 lst$c(81)


###################################################
### chunk number 21: 
###################################################
#line 378 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
 lst[1]


###################################################
### chunk number 22: 
###################################################
#line 382 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
 lst[[1]]


###################################################
### chunk number 23: 
###################################################
#line 400 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
 lst$a
 lst[["a"]]


###################################################
### chunk number 24: dataFrameEx
###################################################
#line 430 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
df <- 
    data.frame(type=rep(c("case", "control"), c(2, 3)), 
               time=rexp(5))
df
df$time


###################################################
### chunk number 25: dataFrameEx2
###################################################
#line 443 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
names(df)
rn <- paste("id", 1:5, sep="")
rownames(df) <- rn
df[1:2, ]


###################################################
### chunk number 26: env1
###################################################
#line 459 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
e1 = new.env()
e1[["a"]] <- 1:3
assign("b", "ciao", e1)
ls(e1)


###################################################
### chunk number 27: 
###################################################
#line 477 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
 mget(c("a", "b"), e1)


###################################################
### chunk number 28: 
###################################################
#line 483 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
 e1$a
 e1[["b"]]


###################################################
### chunk number 29: 
###################################################
#line 495 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
 lst[[1]] = list(2,3)
 lst[[1]]

 e1$b = 1:10
 e1$b


###################################################
### chunk number 30: apply1
###################################################
#line 549 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
a = matrix(runif(1e6), ncol=10)
## 'apply'
s1 = apply(a, 1, sum)

## 'for', pre-allocating for efficiency
s2 = numeric(nrow(a))
for(i in 1:nrow(a))
  s2[i] = sum(a[i,])

## purpose-built function (much faster!)
s3 = rowSums(a)


###################################################
### chunk number 31: sqfun
###################################################
#line 584 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
 square = function(x)
{
    x * x
}
square(10)


###################################################
### chunk number 32: sf2
###################################################
#line 594 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
 square(1:4)


###################################################
### chunk number 33: callsumsq
###################################################
#line 605 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
 sumsq = function(x) sum(square(x))
 sumsq(1:10)


###################################################
### chunk number 34: codeblock eval=FALSE
###################################################
## #line 650 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
## df <- data.frame("y" = 1:10, "x" = rnorm(10))
## plot(df$x, df$y, col = "red")


###################################################
### chunk number 35: codeblock eval=FALSE
###################################################
## #line 668 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
## xyplot( y ~ x | c, data , groups = g)


###################################################
### chunk number 36:  eval=FALSE
###################################################
## #line 699 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
##  source("http://bioconductor.org/biocLite.R")
##  biocLite("Biobase")


###################################################
### chunk number 37:  eval=FALSE
###################################################
## #line 705 "E:/SinglePackageBuilder/job_42_merlot2/IWB2011/inst/doc/R-Introduction.Rnw"
##  library(Biobase)

==> IWB2011_1.0.0.zip: IWB2011/doc/R-Introduction.R <==
###################################################
### chunk number 1: setup
###################################################
#line 17 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
options(width = 40)


###################################################
### chunk number 2: vectors
###################################################
#line 58 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
v <- 123
s <- "a string"
t <- TRUE
letters            # 'letters' is a built-in variable
length(letters)    # 'length' is a function


###################################################
### chunk number 3: vectorsRepAndSeq
###################################################
#line 75 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
seq(1, 3) 
1:3
rep(1:2, 3)
vector(mode="character", length=5)


###################################################
### chunk number 4: names1
###################################################
#line 90 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
x <- c(a=0, b=2)
x
names(x) <- c("Australia", "Brazil")
x


###################################################
### chunk number 5: posind
###################################################
#line 119 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
x <- 1:10
x[2]
x[1:3]


###################################################
### chunk number 6: posind2
###################################################
#line 126 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
 x[9:11]


###################################################
### chunk number 7: posind3
###################################################
#line 138 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
x[0:1]
x[c(0, 0, 0)]


###################################################
### chunk number 8: posind4
###################################################
#line 144 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
x[c(10, 2, NA)]


###################################################
### chunk number 9: posassign
###################################################
#line 155 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
x[2] <- 200
x[8:10] <- 10
x


###################################################
### chunk number 10: negsub
###################################################
#line 170 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
x[-(1:3)]


###################################################
### chunk number 11: negassignb
###################################################
#line 189 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
x = 1:10
x[-(8:10)] = 10
x


###################################################
### chunk number 12: logicalsub
###################################################
#line 205 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
x = 1:10
x > 5
x[x > 5]


###################################################
### chunk number 13: namedsub
###################################################
#line 225 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
x <- c(a=1, b=2, c=3)
x[c("c", "a", "foo")]



###################################################
### chunk number 14: vec1
###################################################
#line 243 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
1:3 + 10:12


###################################################
### chunk number 15: vec2
###################################################
#line 248 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
 1 + 1:5
 paste(1:5, "A", sep="")


###################################################
### chunk number 16: factor
###################################################
#line 266 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
col <- c("red", "green", "red", "yellow", "red")
factor(col)


###################################################
### chunk number 17: matrixEx
###################################################
#line 283 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
x <- matrix(1:10, nrow=2)
dim(x)
x
as.vector(x)


###################################################
### chunk number 18: names2
###################################################
#line 292 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
x <- matrix(c(4, 8, 5, 6, 4, 2, 1, 5, 7), nrow=3)
dimnames(x) <- list(
  year = c("2005", "2006", "2007"), 
  "mode of transport" = c("plane", "bus", "boat"))
x


###################################################
### chunk number 19: arraysub
###################################################
#line 322 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
 x = matrix(1:9, ncol=3)
 x[ x > 6 ]
 x[row(x) > col(x)] = 0
 x


###################################################
### chunk number 20: listenv
###################################################
#line 340 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
 lst = list(a=1:3, b = "ciao", c = sqrt)
 lst
 lst$c(81)


###################################################
### chunk number 21: 
###################################################
#line 378 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
 lst[1]


###################################################
### chunk number 22: 
###################################################
#line 382 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
 lst[[1]]


###################################################
### chunk number 23: 
###################################################
#line 400 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
 lst$a
 lst[["a"]]


###################################################
### chunk number 24: dataFrameEx
###################################################
#line 430 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
df <- 
    data.frame(type=rep(c("case", "control"), c(2, 3)), 
               time=rexp(5))
df
df$time


###################################################
### chunk number 25: dataFrameEx2
###################################################
#line 443 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
names(df)
rn <- paste("id", 1:5, sep="")
rownames(df) <- rn
df[1:2, ]


###################################################
### chunk number 26: env1
###################################################
#line 459 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
e1 = new.env()
e1[["a"]] <- 1:3
assign("b", "ciao", e1)
ls(e1)


###################################################
### chunk number 27: 
###################################################
#line 477 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
 mget(c("a", "b"), e1)


###################################################
### chunk number 28: 
###################################################
#line 483 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
 e1$a
 e1[["b"]]


###################################################
### chunk number 29: 
###################################################
#line 495 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
 lst[[1]] = list(2,3)
 lst[[1]]

 e1$b = 1:10
 e1$b


###################################################
### chunk number 30: apply1
###################################################
#line 549 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
a = matrix(runif(1e6), ncol=10)
## 'apply'
s1 = apply(a, 1, sum)

## 'for', pre-allocating for efficiency
s2 = numeric(nrow(a))
for(i in 1:nrow(a))
  s2[i] = sum(a[i,])

## purpose-built function (much faster!)
s3 = rowSums(a)


###################################################
### chunk number 31: sqfun
###################################################
#line 584 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
 square = function(x)
{
    x * x
}
square(10)


###################################################
### chunk number 32: sf2
###################################################
#line 594 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
 square(1:4)


###################################################
### chunk number 33: callsumsq
###################################################
#line 605 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
 sumsq = function(x) sum(square(x))
 sumsq(1:10)


###################################################
### chunk number 34: codeblock eval=FALSE
###################################################
## #line 650 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
## df <- data.frame("y" = 1:10, "x" = rnorm(10))
## plot(df$x, df$y, col = "red")


###################################################
### chunk number 35: codeblock eval=FALSE
###################################################
## #line 668 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
## xyplot( y ~ x | c, data , groups = g)


###################################################
### chunk number 36:  eval=FALSE
###################################################
## #line 699 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
##  source("http://bioconductor.org/biocLite.R")
##  biocLite("Biobase")


###################################################
### chunk number 37:  eval=FALSE
###################################################
## #line 705 "e:/packagebuilder/jobs/IWB2011_20110204121253/IWB2011/inst/doc/R-Introduction.Rnw"
##  library(Biobase)
